==> haskell-persistent-2.14.5.1-10-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent
version:              2.14.5.1
visibility:           public
id:                   persistent-2.14.5.1-Lra5mco7v3oDrLn8V2e89
key:                  persistent-2.14.5.1-Lra5mco7v3oDrLn8V2e89
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  12dbc6e2f879a15380cd2be2f947cb66
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-2.14.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-2.14.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.5.1-Lra5mco7v3oDrLn8V2e89
depends:
    aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8
    attoparsec-0.14.4-HEPxPDNq5mJKRZZEtIXOMd base-4.16.4.0
    base64-bytestring-1.2.1.0-FdWgvlJbicB4WMe5vVN4jG
    blaze-html-0.9.1.2-6wRAerZ4BzkA8WiagtXagU bytestring-0.11.4.0
    conduit-1.3.5-m4mJvLp39j4uQ7WG40JEh containers-0.6.5.1
    deepseq-1.4.6.1 fast-logger-3.1.2-Bi8VQ8HPeuVEC8AnlB0WGS
    http-api-data-0.5.1-KHPtk8Lg8llBKKAQgMalej
    lift-type-0.1.1.1-8yauYdRyTgY7ZalqHTOZOe
    monad-logger-0.3.40-IGuplPtapPo80SzOUYqwUL mtl-2.2.2
    path-pieces-0.2.1-E15XfVOwfTfIr2VliI4YGA
    resource-pool-0.2.3.2-LMVWhOxYjv3756PAY3BjzE
    resourcet-1.2.6-5BnvDTZXmqJCsWMY1Zflgy
    scientific-0.3.7.0-KUJ0yQBDqbB75MLhDe7uzc
    silently-1.2.5.3-ELa4xfIWJNsGKlyJ7FNmrT template-haskell-2.18.0.0
    text-1.2.5.0 th-lift-instances-0.1.20-IIA6wf2jfwL4V6JOBckTBp
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-0.2.25.0-6K9Ng7p6rr9LEnr4NThT03
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    vault-0.3.1.5-JqfiBpBvd5f8D8LafNRZDu
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.14.5.1-29-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent
version:              2.14.5.1
visibility:           public
id:                   persistent-2.14.5.1-18Wt2qDE1QV8HG32f1oXLN
key:                  persistent-2.14.5.1-18Wt2qDE1QV8HG32f1oXLN
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  d761de8f67b34ae62467b2994e1871a7
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Migration Database.Persist.Sql.Types.Internal
    Database.Persist.Sql.Util Database.Persist.SqlBackend
    Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.SqlPoolHooks
    Database.Persist.SqlBackend.Internal.Statement
    Database.Persist.SqlBackend.Internal.StatementCache
    Database.Persist.SqlBackend.SqlPoolHooks
    Database.Persist.SqlBackend.StatementCache Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Internal
    Database.Persist.Sql.Types Database.Persist.Sql.Raw
    Database.Persist.Sql.Run Database.Persist.Sql.Class
    Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-9.2.8/site-local/persistent-2.14.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/persistent-2.14.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent
hs-libraries:         HSpersistent-2.14.5.1-18Wt2qDE1QV8HG32f1oXLN
depends:
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    base64-bytestring-1.2.1.0-DECs32jOMrhU6x3ypSYAj
    blaze-html-0.9.2.0-83dGvLlliMHJ0KNCx2IkOp bytestring-0.11.4.0
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x containers-0.6.5.1
    deepseq-1.4.6.1 fast-logger-3.1.2-AQtkpPEy7zzKpf61wl8oWJ
    http-api-data-0.5.1-2BBAlVaYv607qWIFAG4oWp
    lift-type-0.1.1.1-8yauYdRyTgY7ZalqHTOZOe
    monad-logger-0.3.40-2U6wkfWu2pa7AyH1VLvETa mtl-2.2.2
    path-pieces-0.2.1-E15XfVOwfTfIr2VliI4YGA
    resource-pool-0.2.3.2-2ghaoAEpV2r22WQ70y4rca
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD
    silently-1.2.5.3-ELa4xfIWJNsGKlyJ7FNmrT template-haskell-2.18.0.0
    text-1.2.5.0 th-lift-instances-0.1.20-7UUlrTsIDWL3XQkjxcQngm
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-0.2.25.0-LM0KsdTS0NHVSVsirPxfP
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    vault-0.3.1.5-1WZud07yl3a9ZcipFufCGQ
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
